import pickle
import sys

from backtranslate.fasta import fasta
import samples


def getProbes(config):
    try:
        p = fasta(config.seedname)
        config.logger.info("Load protein sequences from file : %s" % config.seedname)
    except IOError:
        p = getattr(samples,config.seedname)
        config.logger.info("Load protein internal dataset : %s" % config.seedname)
            
    if "matK" in p:
        gp = ['accD',
              'atpA','atpB','atpE','atpH',
              'ccsA',
              'cemA',
              'clpP',
              'matK',
              'ndhA',
              'petA','petG',
              'psbA','psbB','psbC','psbD','psbE','psbF','psbH','psbI','psbJ','psbK','psbL','psbM','psbN','psbT','psbZ',
              'psaA','psaB','psaC',
              'rbcL',
              'rpl12','rpl14','rpl16','rpl23','rpl32','rpl36',
              'rpoA','rpoB','rpoC1','rpoC2',
              "rps2","rps4","rps7",'rps8','rps12',"rps18",'rpl14',
              'ycf1',
              ]

        p=dict(x for x in p.items() if x[0] in gp)
        
    return p

def getSeeds(index,protein,config):
    # looks if the internal blast was already run            
                
    try:
        # yes, load the previous results
        seeds = pickle.load(open(config.outputname+'.omx'))
        config.logger.info("Load protein match from previous run : %d matches" % sum(len(seeds[i]) for i in seeds))
    except: 
        # no, run it and save the results
        config.logger.info("Running protein matching against reads...")
        seeds = index.lookForSeeds(protein,mincov=config.seedmincov)
        config.logger.info("==> %d matches" % sum(len(seeds[i]) for i in seeds))

        pickle.dump(seeds,open(config.outputname+'.omx',"w"))

    return seeds